package com.cours.dao;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.SessionFactory;
import org.hibernate.Transaction;
import org.hibernate.boot.registry.StandardServiceRegistryBuilder;
import org.hibernate.cfg.Configuration;

public class HibernateUtil {
	private static final Log log = LogFactory.getLog(HibernateUtil.class);
	private static SessionFactory sessionFactory;

	private static SessionFactory buildSessionFactory() {
		try {
			Configuration configuration = new Configuration().addResource("hibernate.cfg.xml").configure();
			StandardServiceRegistryBuilder registryBuilder = new StandardServiceRegistryBuilder()
					.applySettings(configuration.getProperties());
			sessionFactory = configuration.buildSessionFactory(registryBuilder.build());
		} catch (Exception e) {
			log.error("Erreur lors de la construction de la SessionFactory , Exception :  " + e);
		}
		return sessionFactory;
	}

	public static SessionFactory getSessionFactory() {
		if (sessionFactory == null)
			sessionFactory = buildSessionFactory();
		return sessionFactory;
	}

	public static void closeSessionFactoryResources(SessionFactory sessionFactory) {
		try {
			if (sessionFactory != null && !sessionFactory.isClosed()) {
				sessionFactory.close();
			}
		} catch (Exception e) {
			log.error("Erreur lors de la fermeture de la SessionFactory , Exception :  " + e);
		}
	}

	public static void rollBack(Transaction transaction) {
		try {
			// RollBack
			if (transaction != null && transaction.isActive()) {
				transaction.rollback();
			}
		} catch (Exception exRollBack) {
			log.error("Une erreur s'est produite lors du RollBack, Exception : " + exRollBack.getMessage()
					+ " , Exception : " + exRollBack);
		}
	}
}
