package com.cours.main;

import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.hibernate.Transaction;

import com.cours.dao.HibernateUtil;
import com.cours.entities.Personne;

public class MainApp {

	private static final Log log = LogFactory.getLog(MainApp.class);

	public static void main(String[] args) {
		testConfigurationJpaHibernate();
		findAllPersonnes();
		Personne personCRUD = findPersonneById(5);
		personCRUD = new Personne("SessionFactory--Edouard", "SessionFactory--Green", 100.0, 170.0, "rue du paradis",
				"Rouen", "76000", "France");
		personCRUD = createPersonne(personCRUD);
		personCRUD.setPrenom("SessionFactory--Edouard Bis");
		personCRUD.setNom("SessionFactory--Green Bis");
		personCRUD = updatePersonne(personCRUD);
		deletePersonne(personCRUD);
	}

	public static void testConfigurationJpaHibernate() {
		SessionFactory sessionFactory = null;
		Session session = null;
		Transaction transaction = null;
		try {
			// Get Session
			sessionFactory = HibernateUtil.getSessionFactory();
			log.debug("CREATION SessionFactory AVEC SUCCES");
			session = sessionFactory.openSession();
			log.debug("CREATION Session AVEC SUCCES");
			log.debug("AVANT BEGIN TRANSACTION");
			transaction = session.beginTransaction();
			log.debug("APRES BEGIN TRANSACTION");
			transaction.commit();
			log.debug("APRES COMMIT TRANSACTION");
		} catch (Exception e) {
			HibernateUtil.rollBack(transaction);
			log.error("Une erreur s'est produite lors de l'execution la methode, Exception : " + e.getMessage()
					+ " , Exception : " + e);
		} finally {
			// libération ressources
			log.debug("DEBUT FINALEMENT APRES LES CLOSES");
			HibernateUtil.closeSessionFactoryResources(sessionFactory);
			log.debug("FIN FINALEMENT APRES LES CLOSES");
		}
	}

	public static void findAllPersonnes() {
		List<Personne> personnes = null;
		SessionFactory sessionFactory = null;
		Session session = null;
		try {
			sessionFactory = HibernateUtil.getSessionFactory();
			session = sessionFactory.openSession();
			personnes = session.createCriteria(Personne.class).list();
			log.debug("personnes : " + personnes);
		} catch (Exception e) {
			log.error("Une erreur s'est produite lors de l'execution la methode, Exception : " + e.getMessage()
					+ " , Exception : " + e);
		} finally {
			HibernateUtil.closeSessionFactoryResources(sessionFactory);
		}
	}

	public static Personne findPersonneById(Integer idPersonne) {
		Personne personReturn = null;
		List<Personne> personnes = null;
		SessionFactory sessionFactory = null;
		Session session = null;
		try {
			sessionFactory = HibernateUtil.getSessionFactory();
			session = sessionFactory.openSession();
			personReturn = (Personne) session.get(Personne.class, idPersonne);
			log.debug("personnes : " + personnes);
		} catch (Exception e) {
			log.error("Une erreur s'est produite lors de l'execution la methode, Exception : " + e.getMessage()
					+ " , Exception : " + e);
		} finally {
			HibernateUtil.closeSessionFactoryResources(sessionFactory);
		}
		return personReturn;
	}

	public static Personne createPersonne(Personne person) {
		SessionFactory sessionFactory = null;
		Session session = null;
		Transaction transaction = null;
		try {
			sessionFactory = HibernateUtil.getSessionFactory();
			session = sessionFactory.openSession();
			transaction = session.beginTransaction();
			session.saveOrUpdate(person);
			transaction.commit();
		} catch (Exception e) {
			HibernateUtil.rollBack(transaction);
			log.error("Une erreur s'est produite lors de l'execution la methode, Exception : " + e.getMessage()
					+ " , Exception : " + e);
		} finally {
			HibernateUtil.closeSessionFactoryResources(sessionFactory);
		}
		log.debug("person : " + person);
		return person;
	}

	public static Personne updatePersonne(Personne person) {
		SessionFactory sessionFactory = null;
		Session session = null;
		Transaction transaction = null;
		try {
			sessionFactory = HibernateUtil.getSessionFactory();
			session = sessionFactory.openSession();
			transaction = session.beginTransaction();
			session.saveOrUpdate(person);
			transaction.commit();
		} catch (Exception e) {
			HibernateUtil.rollBack(transaction);
			log.error("Une erreur s'est produite lors de l'execution la methode, Exception : " + e.getMessage()
					+ " , Exception : " + e);
		} finally {
			HibernateUtil.closeSessionFactoryResources(sessionFactory);
		}
		log.debug("person : " + person);
		return person;
	}

	public static Personne deletePersonne(Personne person) {
		SessionFactory sessionFactory = null;
		Session session = null;
		Transaction transaction = null;
		try {
			sessionFactory = HibernateUtil.getSessionFactory();
			session = sessionFactory.openSession();
			transaction = session.beginTransaction();
			session.delete(person);
			transaction.commit();
		} catch (Exception e) {
			HibernateUtil.rollBack(transaction);
			log.error("Une erreur s'est produite lors de l'execution la methode, Exception : " + e.getMessage()
					+ " , Exception : " + e);
		} finally {
			HibernateUtil.closeSessionFactoryResources(sessionFactory);
		}
		log.debug("person : " + person);
		person = findPersonneById(person.getIdPersonne());
		log.debug("person : " + person);
		return person;
	}
}
